import{r as s,j as d}from"./vendor-react-CGAml-me.js";import{f as t}from"./index-BoGb7ncW.js";const o=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:t("rounded-xl bg-card text-card-foreground transition-all duration-200 hover:-translate-y-0.5",a),style:{boxShadow:"var(--shadow-card)"},...r}));o.displayName="Card";const i=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:t("flex flex-col space-y-1.5 p-6",a),...r}));i.displayName="CardHeader";const n=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:t("font-semibold leading-none tracking-tight",a),...r}));n.displayName="CardTitle";const l=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:t("text-sm text-muted-foreground",a),...r}));l.displayName="CardDescription";const c=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:t("p-6 pt-0",a),...r}));c.displayName="CardContent";const f=s.forwardRef(({className:a,...r},e)=>d.jsx("div",{ref:e,className:t("flex items-center p-6 pt-0",a),...r}));f.displayName="CardFooter";export{o as C,i as a,n as b,l as c,c as d};
