import{r as i,j as t}from"./vendor-react-CGAml-me.js";import{Y as c,Z as n,_ as r,$ as f}from"./vendor-radix-Hvp89ZoW.js";import{f as o}from"./index-BoGb7ncW.js";const p=c,d=i.forwardRef(({className:e,...s},a)=>t.jsx(n,{ref:a,className:o("inline-flex h-9 items-center justify-center rounded-lg bg-muted p-1 text-muted-foreground",e),...s}));d.displayName=n.displayName;const l=i.forwardRef(({className:e,...s},a)=>t.jsx(r,{ref:a,className:o("inline-flex items-center justify-center whitespace-nowrap rounded-md px-3 py-1 text-sm font-medium ring-offset-background transition-all focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50 data-[state=active]:bg-background data-[state=active]:text-foreground data-[state=active]:shadow",e),...s}));l.displayName=r.displayName;const m=i.forwardRef(({className:e,...s},a)=>t.jsx(f,{ref:a,className:o("mt-2 ring-offset-background focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2",e),...s}));m.displayName=f.displayName;export{p as T,d as a,l as b,m as c};
