import{r as i,j as e}from"./vendor-react-CGAml-me.js";import{a0 as a,a1 as n}from"./vendor-radix-Hvp89ZoW.js";import{f as s}from"./index-BoGb7ncW.js";const c=i.forwardRef(({className:r,...t},o)=>e.jsx(a,{className:s("peer inline-flex h-5 w-9 shrink-0 cursor-pointer items-center rounded-full border-2 border-transparent shadow-sm transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 focus-visible:ring-offset-background disabled:cursor-not-allowed disabled:opacity-50 data-[state=checked]:bg-primary data-[state=unchecked]:bg-input",r),...t,ref:o,children:e.jsx(n,{className:s("pointer-events-none block h-4 w-4 rounded-full bg-background shadow-lg ring-0 transition-transform data-[state=checked]:translate-x-4 data-[state=unchecked]:translate-x-0")})}));c.displayName=a.displayName;export{c as S};
