import{r as l,j as s}from"./vendor-react-CGAml-me.js";import{J as v,K as A,M as i,N as n,Q as c,U as m,W as f,X as x}from"./vendor-radix-Hvp89ZoW.js";import{f as o,K as p}from"./index-BoGb7ncW.js";import{u as C}from"./vendor-i18n-DzUOdQ2j.js";const k=v,H=A,b=l.forwardRef(({className:a,...e},t)=>s.jsx(x,{className:o("fixed inset-0 z-50 bg-black/80 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0",a),...e,ref:t}));b.displayName=x.displayName;const N=l.forwardRef(({className:a,...e},t)=>s.jsxs(H,{children:[s.jsx(b,{}),s.jsx(i,{ref:t,className:o("fixed left-[50%] top-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border bg-background p-6 shadow-lg duration-200 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-left-1/2 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-left-1/2 data-[state=open]:slide-in-from-top-[48%] sm:rounded-lg",a),...e})]}));N.displayName=i.displayName;const u=({className:a,...e})=>s.jsx("div",{className:o("flex flex-col space-y-2 text-center sm:text-left",a),...e});u.displayName="AlertDialogHeader";const g=({className:a,...e})=>s.jsx("div",{className:o("flex flex-col-reverse sm:flex-row sm:justify-end sm:space-x-2",a),...e});g.displayName="AlertDialogFooter";const y=l.forwardRef(({className:a,...e},t)=>s.jsx(n,{ref:t,className:o("text-lg font-semibold",a),...e}));y.displayName=n.displayName;const j=l.forwardRef(({className:a,...e},t)=>s.jsx(c,{ref:t,className:o("text-sm text-muted-foreground",a),...e}));j.displayName=c.displayName;const h=l.forwardRef(({className:a,...e},t)=>s.jsx(f,{ref:t,className:o(p(),a),...e}));h.displayName=f.displayName;const w=l.forwardRef(({className:a,...e},t)=>s.jsx(m,{ref:t,className:o(p({variant:"outline"}),"mt-2 sm:mt-0",a),...e}));w.displayName=m.displayName;function V({open:a,title:e,description:t,onConfirm:T,onCancel:r,destructive:R=!1}){const{t:d}=C();return s.jsx(k,{open:a,onOpenChange:D=>!D&&r(),children:s.jsxs(N,{children:[s.jsxs(u,{children:[s.jsx(y,{children:e}),s.jsx(j,{children:t})]}),s.jsxs(g,{children:[s.jsx(w,{onClick:r,children:d("common.cancel")}),s.jsx(h,{onClick:T,className:R?"bg-destructive text-destructive-foreground hover:bg-destructive/90":"",children:d("common.confirm")})]})]})})}const z=l.forwardRef(({className:a,...e},t)=>s.jsx("div",{className:"relative w-full overflow-auto",children:s.jsx("table",{ref:t,className:o("w-full caption-bottom text-sm",a),...e})}));z.displayName="Table";const F=l.forwardRef(({className:a,...e},t)=>s.jsx("thead",{ref:t,className:o("[&_tr]:border-b",a),...e}));F.displayName="TableHeader";const O=l.forwardRef(({className:a,...e},t)=>s.jsx("tbody",{ref:t,className:o("[&_tr:last-child]:border-0",a),...e}));O.displayName="TableBody";const B=l.forwardRef(({className:a,...e},t)=>s.jsx("tfoot",{ref:t,className:o("border-t bg-muted/50 font-medium [&>tr]:last:border-b-0",a),...e}));B.displayName="TableFooter";const E=l.forwardRef(({className:a,...e},t)=>s.jsx("tr",{ref:t,className:o("border-b transition-colors hover:bg-muted/50 data-[state=selected]:bg-muted",a),...e}));E.displayName="TableRow";const K=l.forwardRef(({className:a,...e},t)=>s.jsx("th",{ref:t,className:o("h-10 px-2 text-left align-middle font-medium text-muted-foreground [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",a),...e}));K.displayName="TableHead";const P=l.forwardRef(({className:a,...e},t)=>s.jsx("td",{ref:t,className:o("p-2 align-middle [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",a),...e}));P.displayName="TableCell";const _=l.forwardRef(({className:a,...e},t)=>s.jsx("caption",{ref:t,className:o("mt-4 text-sm text-muted-foreground",a),...e}));_.displayName="TableCaption";export{V as C,z as T,F as a,E as b,K as c,O as d,P as e};
