if(!self.define){let s,e={};const n=(n,l)=>(n=new URL(n+".js",l).href,e[n]||new Promise(e=>{if("document"in self){const s=document.createElement("script");s.src=n,s.onload=e,document.head.appendChild(s)}else s=n,importScripts(n),e()}).then(()=>{let s=e[n];if(!s)throw new Error(`Module ${n} didn’t register its module`);return s}));self.define=(l,r)=>{const i=s||("document"in self?document.currentScript.src:"")||location.href;if(e[i])return;let a={};const o=s=>n(s,i),u={module:{uri:i},exports:a,require:o};e[i]=Promise.all(l.map(s=>u[s]||o(s))).then(s=>(r(...s),a))}}define(["./workbox-3e722498"],function(s){"use strict";self.skipWaiting(),s.clientsClaim(),s.precacheAndRoute([{url:"logo.png",revision:"7314384b59598d0528d2f6bd911f5f90"},{url:"index.html",revision:"27a48ef133f18dd8f162e165c2c90187"},{url:"icon.png",revision:"7ad8d150424db3a152c232e87ba0145b"},{url:"app-64x64.png",revision:"71b6ebdae41ab885d77a1a9e9377367c"},{url:"app-512x512.png",revision:"1122a768f0a15d689c203fddce2ea581"},{url:"app-192x192.png",revision:"022da84284bcaec81b60c066832bac35"},{url:"app-180x180.png",revision:"1adc541193af9556bc20868d0c65424f"},{url:"app-152x152.png",revision:"b17ac0d24bce2a865c09c2ac61ecda5b"},{url:"app-144x144.png",revision:"c6ffafa0672d8e12935097a6a124ab0c"},{url:"app-120x120.png",revision:"894d6de89ec557d51ea5f25028e78b3d"},{url:"assets/workbox-window.prod.es5-vqzQaGvo.js",revision:null},{url:"assets/vendor-react-CGAml-me.js",revision:null},{url:"assets/vendor-radix-Hvp89ZoW.js",revision:null},{url:"assets/vendor-query-BbgYCJYB.js",revision:null},{url:"assets/vendor-markdown-BvDOff2C.js",revision:null},{url:"assets/vendor-icons-JKgav82F.js",revision:null},{url:"assets/vendor-i18n-DzUOdQ2j.js",revision:null},{url:"assets/useSkills-CWMBRUcZ.js",revision:null},{url:"assets/useSessions-CsyIjfGr.js",revision:null},{url:"assets/useCron-9V5IT7X8.js",revision:null},{url:"assets/useChannels-FFdljGck.js",revision:null},{url:"assets/tooltip-DAbKaoDe.js",revision:null},{url:"assets/textarea-Bim3BD16.js",revision:null},{url:"assets/tabs-SvNNR0JB.js",revision:null},{url:"assets/table-DFNexYWN.js",revision:null},{url:"assets/switch-UZw2myQG.js",revision:null},{url:"assets/skeleton-Bewm4IiF.js",revision:null},{url:"assets/jetbrains-mono-latin-ext-400-normal-Bc8Ftmh3.woff2",revision:null},{url:"assets/jetbrains-mono-latin-400-normal-V6pRDFza.woff2",revision:null},{url:"assets/jetbrains-mono-greek-400-normal-C190GLew.woff2",revision:null},{url:"assets/jetbrains-mono-cyrillic-400-normal-BEIGL1Tu.woff2",revision:null},{url:"assets/inter-vietnamese-400-normal-DMkecbls.woff2",revision:null},{url:"assets/inter-latin-ext-400-normal-C1nco2VV.woff2",revision:null},{url:"assets/inter-latin-400-normal-C38fXH4l.woff2",revision:null},{url:"assets/inter-greek-ext-400-normal-DGGRlc-M.woff2",revision:null},{url:"assets/inter-greek-400-normal-B4URO6DV.woff2",revision:null},{url:"assets/inter-cyrillic-ext-400-normal-BQZuk6qB.woff2",revision:null},{url:"assets/inter-cyrillic-400-normal-obahsSVq.woff2",revision:null},{url:"assets/index-h4GMqzs8.css",revision:null},{url:"assets/index-BoGb7ncW.js",revision:null},{url:"assets/channelIcons-BlOHhb0-.js",revision:null},{url:"assets/card-C65ifeRR.js",revision:null},{url:"assets/badge-DpPviVrw.js",revision:null},{url:"assets/Users-BGQH6aiS.js",revision:null},{url:"assets/Tools-tWPBuZhu.js",revision:null},{url:"assets/SystemConfig-BDkDSrAa.js",revision:null},{url:"assets/Settings-DWVV6ik4.js",revision:null},{url:"assets/SecretInput-ClN-CrEG.js",revision:null},{url:"assets/Login-DohZQpLC.js",revision:null},{url:"assets/Dashboard-BbKwu8xB.js",revision:null},{url:"assets/CronJobs-BOLs_-d8.js",revision:null},{url:"assets/Chat-DbElTtwS.js",revision:null},{url:"assets/Channels-DdujQkcc.js",revision:null},{url:"app-120x120.png",revision:"894d6de89ec557d51ea5f25028e78b3d"},{url:"app-144x144.png",revision:"c6ffafa0672d8e12935097a6a124ab0c"},{url:"app-152x152.png",revision:"b17ac0d24bce2a865c09c2ac61ecda5b"},{url:"app-180x180.png",revision:"1adc541193af9556bc20868d0c65424f"},{url:"app-192x192.png",revision:"022da84284bcaec81b60c066832bac35"},{url:"app-512x512.png",revision:"1122a768f0a15d689c203fddce2ea581"},{url:"app-64x64.png",revision:"71b6ebdae41ab885d77a1a9e9377367c"},{url:"icon.png",revision:"7ad8d150424db3a152c232e87ba0145b"},{url:"logo.png",revision:"7314384b59598d0528d2f6bd911f5f90"},{url:"manifest.webmanifest",revision:"b11bcf41601567bff813a4fa248b902a"}],{}),s.cleanupOutdatedCaches(),s.registerRoute(new s.NavigationRoute(s.createHandlerBoundToURL("index.html"),{denylist:[/^\/api\//]})),s.registerRoute(/^\/api\//,new s.NetworkOnly,"GET")});
