import{j as m}from"./vendor-react-CGAml-me.js";import{f as o}from"./index-BoGb7ncW.js";function a({className:r,...e}){return m.jsx("div",{className:o("animate-pulse rounded-md bg-primary/10",r),...e})}export{a as S};
