import{r,j as o}from"./vendor-react-CGAml-me.js";import{B as d,E as m,F as n,G as l,H as t}from"./vendor-radix-Hvp89ZoW.js";import{f as p}from"./index-BoGb7ncW.js";const T=d,u=m,y=n,f=r.forwardRef(({className:a,sideOffset:e=4,...s},i)=>o.jsx(l,{children:o.jsx(t,{ref:i,sideOffset:e,className:p("z-50 overflow-hidden rounded-md bg-primary px-3 py-1.5 text-xs text-primary-foreground animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",a),...s})}));f.displayName=t.displayName;export{T,u as a,y as b,f as c};
